summary refs log tree commit diff
path: root/gnu/packages
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/packages')
-rw-r--r--gnu/packages/avr.scm9
1 files changed, 5 insertions, 4 deletions
diff --git a/gnu/packages/avr.scm b/gnu/packages/avr.scm
index 6eb0ad8dbf..1f99f636e0 100644
--- a/gnu/packages/avr.scm
+++ b/gnu/packages/avr.scm
@@ -97,11 +97,12 @@
        (modify-phases %standard-phases
          (add-before 'unpack 'fix-cpath
            (lambda _
              ;; C_INCLUDE_PATH poses issues for cross-building, leading to
              ;; failures when building avr-libc on 64-bit systems.  Simply
              ;; unsetting it allows the build to succeed because it doesn't
              ;; try to use any of the native system's headers.
              (unsetenv "C_INCLUDE_PATH")
+             (unsetenv "CPATH")
              #t)))))
     (native-inputs `(("avr-binutils" ,avr-binutils)
                      ("avr-gcc" ,avr-gcc)))
@@ -97,11 +97,12 @@
          (add-before 'unpack 'fix-cpath
            (lambda _
-             ;; C_INCLUDE_PATH poses issues for cross-building, leading to
-             ;; failures when building avr-libc on 64-bit systems.  Simply
-             ;; unsetting it allows the build to succeed because it doesn't
-             ;; try to use any of the native system's headers.
+             ;; C_INCLUDE_PATH and CPATH pose issues for cross-building,
+             ;; leading to failures when building avr-libc on 64-bit systems.
+             ;; Simply unsetting them allows the build to succeed because it
+             ;; doesn't try to use any of the native system's headers.
              (unsetenv "C_INCLUDE_PATH")